@@ -1,8 +1,8 @@
 try:  # pragma: no cover
     import collectd
-    collectd_present = True
+    COLLECTD_PRESENT = True
 except (ImportError, AttributeError):  # pragma: no cover
-    collectd_present = False
+    COLLECTD_PRESENT = False
 
 from . metrics_writer import MetricsWriter  # pragma: no cover
 
@@ -11,6 +11,6 @@ def config_callback(conf):  # pragma: no cover
     met_writer.parse_config(conf)
     met_writer.register()
 
-if collectd_present:  # pragma: no cover
+if COLLECTD_PRESENT:  # pragma: no cover
     met_writer = MetricsWriter(collectd)
-    collectd.register_config(config_callback)
\ No newline at end of file
+    collectd.register_config(config_callback)
