@@ -18,10 +18,8 @@ class MetricsBatcher(Timer):
         Init MetricsBatcher with max_batch_size, max_batch_interval, and met_buffer
         """
 
-        Timer.__init__(self, max_batch_interval, self.flush)
-
         self.collectd = collectd
-
+        Timer.__init__(self, max_batch_interval, self.flush)
         # initiate max_batch_size and max_batch_interval
         self.max_batch_size = max_batch_size
         self.max_batch_interval = max_batch_interval
@@ -53,7 +51,7 @@ class MetricsBatcher(Timer):
         if self.queue.empty():
             self.collectd.debug('queue is empty')
             return
-        if self.flushing_lock.acquire(False):
+        if self.flushing_lock.acquire(False):  # pylint: disable=R1732
             batch = self._pop_batch()
             self.collectd.debug('flushing metrics with batch size %d' % len(batch))
             self.metrics_buffer.put_pending_batch(batch)
