@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from .metrics_util import validate_non_empty, validate_string_type, validate_positive, \
-    validate_non_negative, validate_field
+from .metrics_util import (validate_boolean_type, validate_non_empty,
+                           validate_non_negative, validate_positive,
+                           validate_string_type)
 
 
 class ConfigOptions(object):
     """
     Config options
     """
-    types_db = 'TypesDB'
     url = 'URL'
     # Http header options
     dimension_tags = 'Dimensions'
@@ -35,6 +35,8 @@ class ConfigOptions(object):
     # Static option, not configurable yet. Default is application/vnd.sumologic.carbon2
     content_type = 'ContentType'
     shutdown_max_wait = "ShutdownMaxWait"  # seconds
+    add_metric_dimension = 'AddMetricDimension'
+    metric_dimension_separator = 'MetricDimensionSeparator'
 
 class MetricsConfig:
     """
@@ -49,7 +51,6 @@ class MetricsConfig:
         """
         self.collectd = collectd
         self.conf = self.default_config()
-        self.types = {}
 
         collectd.info('Initialized MetricsConfig with default config %s' % self.conf)
 
@@ -68,7 +69,9 @@ class MetricsConfig:
             ConfigOptions.max_requests_to_buffer: 1000,
             ConfigOptions.content_encoding: 'deflate',
             ConfigOptions.content_type: 'application/vnd.sumologic.carbon2',
-            ConfigOptions.shutdown_max_wait: 5
+            ConfigOptions.shutdown_max_wait: 5,
+            ConfigOptions.add_metric_dimension: True,
+            ConfigOptions.metric_dimension_separator: '.',
         }
 
     def parse_config(self, config):
@@ -78,10 +81,7 @@ class MetricsConfig:
 
         try:
             for child in config.children:
-                if child.key == ConfigOptions.types_db:
-                    for _v in child.values:
-                        self._parse_types(_v)
-                elif child.key == ConfigOptions.url:
+                if child.key == ConfigOptions.url:
                     url = child.values[0]
                     self.conf[child.key] = url
                     validate_non_empty(url, child.key)
@@ -118,6 +118,14 @@ class MetricsConfig:
                         raise Exception('Unknown ContentEncoding %s specified. ContentEncoding '
                                         'must be deflate, gzip, or none' % _s)
                     self.conf[child.key] = content_encoding
+                elif child.key == ConfigOptions.add_metric_dimension:
+                    _b = child.values[0]
+                    validate_boolean_type(child.key, _b)
+                    self.conf[child.key] = _b
+                elif child.key == ConfigOptions.metric_dimension_separator:
+                    _s = child.values[0]
+                    validate_string_type(_s, child.key, 'Value', 'Key')
+                    self.conf[child.key] = _s
                 else:
                     self.collectd.warning('Unknown configuration %s, ignored.' % child.key)
         except Exception as e:
@@ -127,8 +135,10 @@ class MetricsConfig:
         if ConfigOptions.url not in self.conf:
             raise Exception('Specify %s in collectd.conf.' % ConfigOptions.url)
 
-        if not self.types:
-            raise Exception('Specify %s in collectd.conf.' % ConfigOptions.types_db)
+        # Set metric dimension separator to None if we do not want to add it
+        if ConfigOptions.add_metric_dimension not in self.conf \
+            or not self.conf[ConfigOptions.add_metric_dimension]:
+            self.conf[ConfigOptions.metric_dimension_separator] = None
 
         http_post_interval = self.conf[ConfigOptions.http_post_interval]
         max_batch_interval = self.conf[ConfigOptions.max_batch_interval]
@@ -146,47 +156,11 @@ class MetricsConfig:
 
         self.collectd.info('Updated MetricsConfig %s with config file %s ' % (self.conf, config))
 
-    # parse types.db file
-    def _parse_types(self, db):
-
-        try:
-            file = open(db, 'r')
-
-            for line in file:
-                fields = line.split()
-                if len(fields) < 2:
-                    continue
-                type_name = fields[0]
-                if type_name[0] == '#':
-                    continue
-                values = []
-                for data_source in fields[1:]:
-                    data_source = data_source.rstrip(',')
-                    ds_fields = data_source.split(':')
-
-                    if len(ds_fields) != 4:
-                        self.collectd.warning('Cannot parse data source %s on type %s'
-                                         % (data_source, type_name))
-                        continue
-                    values.append(ds_fields)
-                self.types[type_name] = values
-
-            file.close()
-
-            self.collectd.info('Parsed types %s with types_db file %s ' % (self.types, db))
-
-        except Exception as e:
-            self.collectd.error('Parse types %s failed with %s' %(db, str(e)))
-            raise e
-
     # parse dimension_tags/meta_tags specified in collectd.conf
     def _parse_tags(self, child):
         if len(child.values) % 2 != 0:
             raise Exception('Missing tags key/value in options %s.' % str(child.values))
 
-        for value in child.values:
-            validate_field(value, child.key, 'Value', 'Key')
-
         self.conf[child.key] = zip(*(iter(child.values),) * 2)
 
         self.collectd.info('Parsed %s tags %s' % (child.key, self.conf[child.key]))
