@@ -2,7 +2,7 @@
 
 import math
 
-from .metrics_util import validate_field, validate_type
+from .metrics_util import sanitize_field
 
 
 class IntrinsicKeys(object):
@@ -13,6 +13,7 @@ class IntrinsicKeys(object):
     type_instance = "type_instance"
     ds_name = "ds_name"
     ds_type = "ds_type"
+    metric = "metric"
 
 
 # reserved keywords are case-insensitive
@@ -24,8 +25,8 @@ def gen_tag(key, value):
     """
     Tag is of form key=value
     """
-    key = validate_field(key, value, 'Key', 'Value')
-    value = validate_field(value, key, 'Value', 'Key')
+    key = sanitize_field(key)
+    value = sanitize_field(value)
     if not key:
         raise Exception('Key for value %s cannot be empty' % value)
 
@@ -82,23 +83,36 @@ def _gen_dimension_tags(data, ds_name, ds_type):
 
     return dimension_tags
 
+def _gen_metric_dimension(data, sep):
+    """
+    Generates metric dimension and returns it as one-element list
+    """
+    if sep is None:
+        return []
 
-def convert_to_metrics(data, types):
+    return [
+        gen_tag(
+            IntrinsicKeys.metric,
+            sep.join(v for v in (data.type, data.type_instance) if v)
+            )
+        ]
+
+def convert_to_metrics(data, data_set, sep):
     """
     Convert data into metrics
     """
-    validate_type(data, types)
-
     metrics = []
+    metric_dimension = _gen_metric_dimension(data, sep)
+    meta_tags = _gen_meta_tags(data)
 
-    for (value, data_type) in zip(data.values, types[data.type]):
+    for (value, data_type) in zip(data.values, data_set):
         if math.isnan(value):
             continue
+
         ds_name = data_type[0]
         ds_type = data_type[1]
 
-        dimension_tags = _gen_dimension_tags(data, ds_name, ds_type)
-        meta_tags = _gen_meta_tags(data)
+        dimension_tags = _gen_dimension_tags(data, ds_name, ds_type) + metric_dimension
         metric = _gen_metric(dimension_tags, meta_tags, value, data.time)
 
         metrics.append(metric)
