@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 _reserved_symbols = {
-    ' ': None,
+    ' ': '_',
     '=': ':',
 }
 
@@ -31,7 +31,17 @@ def validate_string_type(value, field, label1, label2):
                         (label1, value, label2, field, type(value)))
 
 
-def validate_field(value, field, label1, label2):
+def validate_boolean_type(field, value):
+    """
+    Field must be string type
+    """
+
+    if not isinstance(value, bool):
+        raise Exception('Value for %s must be boolean type, but it was "%s"(%s)' %
+                        (field, value, type(value)))
+
+
+def sanitize_field(value):
     """
     Field must be string that does not contains '=' or ' '
     """
@@ -41,30 +51,10 @@ def validate_field(value, field, label1, label2):
 
     for reserved_symbol, replacement in _reserved_symbols.items():
         if reserved_symbol in value:
-            if replacement is None:
-                raise Exception('%s %s for %s %s must not contain reserved symbol \"%s\"' %
-                                (label1, value, label2, field, reserved_symbol))
-
             value = value.replace(reserved_symbol, replacement)
     return value
 
 
-def validate_type(data, types):
-    """
-    Validate type are defined in types.db and matching data values
-    """
-
-    # Verify type is defined in types.db
-    if data.type not in types:
-        raise Exception('Do not know how to handle type %s. Do you have all your types.db files'
-                        ' configured?' % data.type)
-
-    # Verify values conform to the type defined
-    if len(data.values) != len(types[data.type]):
-        raise Exception('Number values %s differ from types defined for %s' %
-                        (data.values, data.type))
-
-
 class RecoverableException(Exception):
     """
     Exception that are recoverable.
