@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 
 import pytest
-from collectd import Helper
+
+from collectd import CollecdMock
 from collectd.values import Values
+
 from sumologic_collectd_metrics.metrics_converter import (convert_to_metrics,
                                                           gen_tag, tags_to_str)
 
@@ -43,6 +45,10 @@ def test_gen_value_not_string_exception():
     assert expected, value
 
 
+def test_gen_value_reserved():
+    assert gen_tag('tag_key space=', 'tag_value=t st') == 'tag_key_space:=tag_value:t_st'
+
+
 def test_tags_to_str():
     tags = ['tag_key1=tag_val1', 'tag_key2=tag_val2', 'tag_key3=tag_val3']
     tag_str = tags_to_str(tags)
@@ -66,50 +72,35 @@ def test_tags_to_str_with_empty_tags():
 
 def test_convert_to_metrics_single():
     data = Values()
-    helper = Helper()
-    metrics = convert_to_metrics(data, helper.types)
+    dataset = CollecdMock().get_dataset('test_type')
+    metrics = convert_to_metrics(data, dataset, None)
 
-    assert metrics == data.metrics_str()
+    assert metrics == data.metrics_str(None)
 
 
 def test_convert_to_metrics_multiple():
     data = Values(type='test_type_2', values=[1.23, 4.56],
                   ds_names=['test_ds_name1', 'test_ds_name2'],
                   ds_types=['test_ds_type1', 'test_ds_type2'])
-    helper = Helper()
-    metrics = convert_to_metrics(data, helper.types)
+    dataset = CollecdMock().get_dataset('test_type_2')
+    metrics = convert_to_metrics(data, dataset, None)
 
-    assert metrics == data.metrics_str()
+    assert metrics == data.metrics_str(None)
 
 
 def test_convert_to_metrics_no_meta():
     data = Values(type='test_type_2', meta={}, values=[1.23, 4.56],
                   ds_names=['test_ds_name1', 'test_ds_name2'],
                   ds_types=['test_ds_type1', 'test_ds_type2'])
-    helper = Helper()
-    metrics = convert_to_metrics(data, helper.types)
+    dataset = CollecdMock().get_dataset('test_type_2')
+    metrics = convert_to_metrics(data, dataset, None)
 
-    assert metrics == data.metrics_str()
+    assert metrics == data.metrics_str(None)
 
 
-def test_convert_to_metrics_type_format_exception():
-    with pytest.raises(Exception) as e:
-        data = Values(type='test_type_2', values=[1.23],
-                      ds_names=['test_ds_name1', 'test_ds_name2'],
-                      ds_types=['test_ds_type1', 'test_ds_type2'])
-        helper = Helper()
-        convert_to_metrics(data, helper.types)
+def test_convert_to_metrics_with_metric_dimension():
+    data = Values()
+    dataset = CollecdMock().get_dataset('test_type')
+    metrics = convert_to_metrics(data, dataset, '_')
 
-    assert 'Number values [1.23] differ from types defined for test_type_2' in str(e)
-
-
-def test_convert_to_metrics_type_nonexist_exception():
-    with pytest.raises(Exception) as e:
-        data = Values(type='test_type_3', values=[1.23],
-                      ds_names=['test_ds_name1', 'test_ds_name2'],
-                      ds_types=['test_ds_type1', 'test_ds_type2'])
-        helper = Helper()
-        convert_to_metrics(data, helper.types)
-
-    assert 'Do not know how to handle type test_type_3. ' \
-           'Do you have all your types.db files configured?' in str(e)
+    assert metrics == data.metrics_str('_')
